local L = AceLibrary("AceLocale-2.2"):new("SalvationVeto")

local options=
{
	type = 'group',
	args =
	{
		combatonly =
		{
			type = 'toggle',
			name = L["Combat Only"],
			desc = L["Remove Salvation buffs only in combat"],
			get = "IsCombatOnly",
			set = "CombatOnlyToggle",
		},
		feedback =
		{
			type = 'toggle',
			name = L["Chat Feedback"],
			desc = L["Show feedback in chat window when buffs are removed"],
			get = "IsChatFeedback",
			set = "ChatFeedbackToggle",
		}
	}
}

SalvationVeto = AceLibrary("AceAddon-2.0"):new("AceConsole-2.0", "AceEvent-2.0", "AceDB-2.0")
SalvationVeto:RegisterChatCommand(L["Slash-Commands"], options)

SalvationVeto:RegisterDB("SalvationVetoDB", "SalvationVetoDBPC")
SalvationVeto:RegisterDefaults("profile", {
	combatOnly = true,
	feedback = true,
} )

function SalvationVeto:OnEnable()
	self:RegisterEvent("PLAYER_AURAS_CHANGED")
	self:RegisterEvent("PLAYER_ENTER_COMBAT")
end

function SalvationVeto:IsCombatOnly()
	return self.db.profile.combatOnly
end

function SalvationVeto:CombatOnlyToggle()
	self.db.profile.combatOnly = not self.db.profile.combatOnly
end

function SalvationVeto:IsChatFeedback()
	return self.db.profile.feedback
end

function SalvationVeto:ChatFeedbackToggle()
	self.db.profile.feedback = not self.db.profile.feedback
end

function SalvationVeto:PLAYER_ENTER_COMBAT()
	if self.db.profile.combatOnly then
		self:RemoveSalvation()
	end
end

function SalvationVeto:PLAYER_AURAS_CHANGED()
	if self.db.profile.combatOnly then
		if UnitAffectingCombat("player") then
			self:RemoveSalvation()
		end
	else
		self:RemoveSalvation()
	end
end

function SalvationVeto:RemoveSalvation()
	for i=1,16,1 do
		name = GetPlayerBuffName(i)
		if name == nil then break end
		if name == "Blessing of Salvation" or name == "Greater Blessing of Salvation" then
			CancelPlayerBuff(name)
			if self.db.profile.feedback then
				self:Print(name .. " removed")
			end
			break
		end
	end
end

